@@ -191,7 +191,7 @@ py_io_channel_read_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
         return NULL;
 	
     if (max_count == 0)
-	return PYGLIB_PyUnicode_FromString("");
+	return PYGLIB_PyBytes_FromString("");
     
     while (status == G_IO_STATUS_NORMAL
 	   && (max_count == -1 || total_read < max_count)) {
@@ -234,23 +234,6 @@ py_io_channel_read_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
 	    goto failure;
     }
 
-#if PY_VERSION_HEX >= 0x03000000
-    /* If this is not UTF8 encoded channel return the raw bytes */
-    if (g_io_channel_get_encoding(self->channel) != NULL)
-        return ret_obj;
-
-    /* convert to Unicode string */
-    {
-	PyObject *unicode_obj;
-
-	unicode_obj = PyUnicode_FromString(PyBytes_AS_STRING(ret_obj));
-	if (unicode_obj == NULL)
-	    goto failure;
-	Py_DECREF(ret_obj);
-	ret_obj = unicode_obj;
-    }
-#endif
-
     return ret_obj;
 
   failure:
@@ -266,14 +249,13 @@ py_io_channel_write_chars(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     Py_ssize_t buf_len;
     gsize count;
     GError* error = NULL;
-    GIOStatus status;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s#:gi._glib.IOChannel.write",
                                      kwlist, &buf, &buf_len))
         return NULL;
 	
     pyglib_unblock_threads();
-    status = g_io_channel_write_chars(self->channel, buf, buf_len, &count, &error);
+    g_io_channel_write_chars(self->channel, buf, buf_len, &count, &error);
     pyglib_block_threads();
     if (pyglib_error_check(&error))
 	return NULL;
@@ -289,7 +271,6 @@ py_io_channel_write_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     Py_ssize_t buf_len;
     gsize count;
     GError* error = NULL;
-    GIOStatus status;
     PyObject *iter, *value, *pylines;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs, "O:gi._glib.IOChannel.writelines",
@@ -300,9 +281,11 @@ py_io_channel_write_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     
     while (1) {
         value = PyIter_Next(iter);
+        if (value == NULL)
+            break;
         if (PyErr_ExceptionMatches(PyExc_StopIteration)) {
             PyErr_Clear();
-            goto normal_exit;
+            break;
         }
         if (!PYGLIB_PyUnicode_Check(value)) {
             PyErr_SetString(PyExc_TypeError, "gi._glib.IOChannel.writelines must"
@@ -312,7 +295,7 @@ py_io_channel_write_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
         }
         PYGLIB_PyUnicode_AsStringAndSize(value, &buf, &buf_len);
         pyglib_unblock_threads();
-        status = g_io_channel_write_chars(self->channel, buf, buf_len, &count, &error);
+        g_io_channel_write_chars(self->channel, buf, buf_len, &count, &error);
         pyglib_unblock_threads();
         Py_DECREF(value);
         if (pyglib_error_check(&error)) {
@@ -320,7 +303,7 @@ py_io_channel_write_lines(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
             return NULL;
         }
     }
-normal_exit:
+
     Py_DECREF(iter);
     Py_INCREF(Py_None);
     return Py_None;
@@ -554,13 +537,12 @@ py_io_channel_read_line(PyGIOChannel* self, PyObject *args, PyObject *kwargs)
     gchar *str_return = NULL;
     GError *error = NULL;
     gint size_hint = -1;
-    GIOStatus status;
 
     if (!PyArg_ParseTupleAndKeywords(args, kwargs, "|i:gi._glib.IOChannel.readline", kwlist,
                                      &size_hint))
         return NULL;
 
-    status = g_io_channel_read_line(self->channel, &str_return, &length,
+    g_io_channel_read_line(self->channel, &str_return, &length,
                                     &terminator_pos, &error);
     if (pyglib_error_check(&error))
         return NULL;
