@@ -83,6 +83,15 @@ _pygi_hash_pointer_to_arg (GIArgument *arg,
         case GI_TYPE_TAG_INT32:
             arg->v_int32 = GPOINTER_TO_INT (arg->v_pointer);
             break;
+        case GI_TYPE_TAG_UINT8:
+            arg->v_uint8 = GPOINTER_TO_UINT (arg->v_pointer);
+            break;
+        case GI_TYPE_TAG_UINT16:
+            arg->v_uint16 = GPOINTER_TO_UINT (arg->v_pointer);
+            break;
+        case GI_TYPE_TAG_UINT32:
+            arg->v_uint32 = GPOINTER_TO_UINT (arg->v_pointer);
+            break;
         case GI_TYPE_TAG_UTF8:
         case GI_TYPE_TAG_FILENAME:
         case GI_TYPE_TAG_INTERFACE:
@@ -810,11 +819,14 @@ _pygi_argument_to_array (GIArgument  *arg,
                     g_assert (callable_info);
                     length_arg_info = g_callable_info_get_arg (callable_info, length_arg_pos);
                     length_type_info = g_arg_info_get_type (length_arg_info);
+                    g_base_info_unref ( (GIBaseInfo *) length_arg_info);
                     if (!gi_argument_to_gssize (args[length_arg_pos],
                                                 g_type_info_get_tag (length_type_info),
                                                 &length)) {
+                        g_base_info_unref ( (GIBaseInfo *) length_type_info);
                         return NULL;
                     }
+                    g_base_info_unref ( (GIBaseInfo *) length_type_info);
                 }
             }
 
@@ -1260,9 +1272,7 @@ array_success:
 
                         arg.v_pointer = closure;
                     } else if (g_struct_info_is_foreign (info)) {
-                        PyObject *result;
-                        result = pygi_struct_foreign_convert_to_g_argument (
-                                     object, info, transfer, &arg);
+                        pygi_struct_foreign_convert_to_g_argument (object, info, transfer, &arg);
                     } else if (g_type_is_a (type, G_TYPE_BOXED)) {
                         if (pyg_boxed_check (object, type)) {
                             arg.v_pointer = pyg_boxed_get (object, void);
@@ -1991,6 +2001,11 @@ _pygi_argument_from_g_value(const GValue *value,
     GIArgument arg = { 0, };
 
     GITypeTag type_tag = g_type_info_get_tag (type_info);
+
+    /* For the long handling: long can be equivalent to
+       int32 or int64, depending on the architecture, but
+       gi doesn't tell us (and same for ulong)
+    */
     switch (type_tag) {
         case GI_TYPE_TAG_BOOLEAN:
             arg.v_boolean = g_value_get_boolean (value);
@@ -1998,18 +2013,30 @@ _pygi_argument_from_g_value(const GValue *value,
         case GI_TYPE_TAG_INT8:
         case GI_TYPE_TAG_INT16:
         case GI_TYPE_TAG_INT32:
-            arg.v_int = g_value_get_int (value);
+	    if (g_type_is_a (G_VALUE_TYPE (value), G_TYPE_LONG))
+		arg.v_int = g_value_get_long (value);
+	    else
+		arg.v_int = g_value_get_int (value);
             break;
         case GI_TYPE_TAG_INT64:
-            arg.v_int64 = g_value_get_int64 (value);
+	    if (g_type_is_a (G_VALUE_TYPE (value), G_TYPE_LONG))
+		arg.v_int64 = g_value_get_long (value);
+	    else
+		arg.v_int64 = g_value_get_int64 (value);
             break;
         case GI_TYPE_TAG_UINT8:
         case GI_TYPE_TAG_UINT16:
         case GI_TYPE_TAG_UINT32:
-            arg.v_uint = g_value_get_uint (value);
+	    if (g_type_is_a (G_VALUE_TYPE (value), G_TYPE_ULONG))
+		arg.v_uint = g_value_get_ulong (value);
+	    else
+		arg.v_uint = g_value_get_uint (value);
             break;
         case GI_TYPE_TAG_UINT64:
-            arg.v_uint64 = g_value_get_uint64 (value);
+	    if (g_type_is_a (G_VALUE_TYPE (value), G_TYPE_ULONG))
+		arg.v_uint64 = g_value_get_ulong (value);
+	    else
+		arg.v_uint64 = g_value_get_uint64 (value);
             break;
         case GI_TYPE_TAG_UNICHAR:
             arg.v_uint32 = g_value_get_schar (value);
