@@ -1437,8 +1437,8 @@ _wrap_g_field_info_set_value (PyGIBaseInfo *self,
 
         if (py_value != Py_None && !PYGLIB_PyLong_Check(py_value)) {
             if (PyErr_WarnEx(PyExc_RuntimeWarning,
-                         "Usage of gpointers to store objects has been deprecated. "
-                         "Please integer values instead, see: https://bugzilla.gnome.org/show_bug.cgi?id=683599",
+                         "Usage of gpointers to store objects is being deprecated. "
+                         "Please use integer values only, see: https://bugzilla.gnome.org/show_bug.cgi?id=683599",
                          1))
                 goto out;
         }
