@@ -89,7 +89,6 @@ _wrap_g_irepository_require (PyGIRepository *self,
     const char *version = NULL;
     PyObject *lazy = NULL;
     GIRepositoryLoadFlags flags = 0;
-    GTypelib *typelib;
     GError *error;
 
     if (!PyArg_ParseTupleAndKeywords (args, kwargs, "s|zO:Repository.require",
@@ -102,7 +101,7 @@ _wrap_g_irepository_require (PyGIRepository *self,
     }
 
     error = NULL;
-    typelib = g_irepository_require (self->repository, namespace_, version, flags, &error);
+    g_irepository_require (self->repository, namespace_, version, flags, &error);
     if (error != NULL) {
         PyErr_SetString (PyGIRepositoryError, error->message);
         g_error_free (error);
