@@ -2,7 +2,8 @@
 
 import unittest
 
-from gi.repository import GLib
+from gi.repository import GLib, GObject
+
 
 class Idle(GLib.Idle):
     def __init__(self, loop):
@@ -88,11 +89,46 @@ class TestSource(unittest.TestCase):
 
         assert dispatched[0]
 
+    def testIsDestroyedSimple(self):
+        s = GLib.Source()
+
+        self.assertFalse(s.is_destroyed())
+        s.destroy()
+        self.assertTrue(s.is_destroyed())
+
+        c = GLib.MainContext()
+        s = GLib.Source()
+        s.attach(c)
+        self.assertFalse(s.is_destroyed())
+        s.destroy()
+        self.assertTrue(s.is_destroyed())
+
+    def testIsDestroyedContext(self):
+        def f():
+            c = GLib.MainContext()
+            s = GLib.Source()
+            s.attach(c)
+            return s
+
+        s = f()
+        self.assertTrue(s.is_destroyed())
+
+    def testRemove(self):
+        s = GLib.idle_add(dir)
+        self.assertEqual(GLib.source_remove(s), True)
+        # s is now removed, should fail now
+        self.assertEqual(GLib.source_remove(s), False)
+
+        # accepts large source IDs (they are unsigned)
+        self.assertEqual(GLib.source_remove(GObject.G_MAXINT32), False)
+        self.assertEqual(GLib.source_remove(GObject.G_MAXINT32 + 1), False)
+        self.assertEqual(GLib.source_remove(GObject.G_MAXUINT32), False)
+
 
 class TestTimeout(unittest.TestCase):
-     def test504337(self):
-        timeout_source = GLib.Timeout(20)
-        idle_source = GLib.Idle()
+    def test504337(self):
+        GLib.Timeout(20)
+        GLib.Idle()
 
 
 if __name__ == '__main__':
